<?php

if (substr((string) $messaggio,0,4) != "var_") {
switch ($messaggio) {

# translate YES and NO in upper case
case "SI":                                          	$messaggio = "JA"; break;
case "NO":                                          	$messaggio = "NEIN"; break;
case "Torna indietro":                          	$messaggio = "Zur&uuml;ck"; break;
case "Crea pagine per il sito web":  		        $messaggio = "Webseiten erzeugen"; break;
case "Dati comuni":                                  	$messaggio = "Allgemeine Daten"; break;
case "Utilizza i dati attuali per la connessione al database":$messaggio = "Benutze die existierenden Daten um mit der Datenbank zu verbinden."; break;
case "Utilizza altri dati per la connessione al database":$messaggio = "Benutze andere Daten um mit der Datenbank zu verbinden"; break;
case "Tipo di database":                          	$messaggio = "Datenbank Typ"; break;
case "Nome del database da utilizzare":          	$messaggio = "Name der Datenbank"; break;
case "Nome del computer a cui collegarsi":          	$messaggio = "Name des Datenbankservers (Hostname)"; break;
case "Numero della porta a cui collegarsi":          	$messaggio = "Port Nummer"; break;
case "Normalmete 5432 per Postgresql o 3306 per Mysql": $messaggio = "Normalerweise 5432 f&uuml;r Postgresql oder 3306 f&uuml;r Mysql"; break;
case "Nome per l'autenticazione al database":          	$messaggio = "Benutzername f&uuml;r die Datenbank"; break;
case "Parola segreta per l'autenticazione al database": $messaggio = "Passwort f&uuml;r die Datenbank"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":        	$messaggio = "Dynamische Bibliotheken \"pgsql.so\" oder \"mysql.so\" laden"; break;
case "Si":                                          	$messaggio = "Ja"; break;
case "No":                                          	$messaggio = "Nein"; break;
case "scegliere si se non viene caricata automaticamente da php": $messaggio = "w&auml;hlen Sie \"Ja\", wenn es nicht automatisch von PHP gestartet wird."; break;
case "Percorso alla directory dati da dove verrà posizionato lo script": $messaggio = "Pfad zum \"dati\" Ordner von wo aus das Skript geladen wird"; break;
case "solo per mysql":                          	$messaggio = "nur f&uuml;r mysql"; break;
case "Anno":                                          	$messaggio = "Jahr"; break;
case "Lingua":                                  	$messaggio = "Sprache"; break;
case "Formato di visualizzazione dei soldi":          	$messaggio = "Geld Anzeigeformat"; break;
case "Formato di visualizzazione delle date":          	$messaggio = "Datum Anzeigeformat"; break;
case "Nome della valuta al singolare":          	$messaggio = "W&auml;hrungsname Einzahl"; break;
case "Nome della valuta al plurale":                  	$messaggio = "W&auml;hrungsname Mehrzahl"; break;
case "Pagina per la disponibilità":  		        $messaggio = "Verf&uuml;gbarkeitsseite"; break;
case "Le date sono sbagliate":                  	$messaggio = "Daten sind falsch"; break;
case "Indirizzo email non valido":                  	$messaggio = "Ung&uuml;ltige E-Mailadresse"; break;
case "INIZIO VARIABILI MODIFICABILI":                  	$messaggio = "ANFANG DER VER&Auml;NDERBAREN VARIABLEN"; break;
case "Inserire in questa variabile il nome della pagina se \$PHP_SELF non è definita":                                                         $messaggio = "Setzen Sie in diese Variable den Namen der Seite, sofern \$PHP_SELF nicht definiert ist."; break;
case "europa":                                  	$messaggio = "Europa"; break;
case "usa":                                          	$messaggio = "USA"; break;
case "FRASI":                                          	$messaggio = "AUSDR&&Uuml;uml;CKE"; break;
case "FRASI EMAIL":                                  	$messaggio = "EMAIL AUSDR&&Uuml;uml;CKE"; break;
case "PERIODI NEI MENU":                          	$messaggio = "MEN&&Uuml;uml; ZEITR&Auml;UME"; break;
case "FINE VARIABILI MODIFICABILI":                  	$messaggio = "ENDE DER VER&Auml;NDERBAREN VARIABLEN"; break;
case "NON MODIFICARE NIENTE A PARTIRE DA QUI":        	$messaggio = "AB HIER NICHTS MEHR &Auml;NDERN"; break;
case "La variabile \\\$PHP_SELF non è definita, si dovrà editare a mano questa pagina per inserirne il nome":        	$messaggio = "Die \\\$PHP_SELF Variable wurde nicht definiert, Sie m&uuml;ssen den Namen per Hand eintragen"; break;
case "Non ho il permesso di scrittura nella cartella":  $messaggio = "Ich habe keine Schreibrecht auf das Verzeichnis"; break;
case "OK":                                          	$messaggio = "OK"; break;
case "Pagina per controllare la disponibilità":	        $messaggio = "Seite um die Verf&uuml;gbarkeit zu pr&uuml;fen"; break;
case "Date nei menù a tendina":                  	$messaggio = "Datum in Aufklapp-Menus"; break;
case "Tariffe (tipologie) da mostrare ed eventuali loro nomi sostitutivi con cui mostrarle":                                                         $messaggio = "Preisstufen zur Anzeige und ihre eventuellen Ersatzbezeichnungen"; break;
case "col nome":                                  	$messaggio = "mit Name"; break;
case "Chiedere se aggiungere i costi presenti nella pagina di inserzione prenotazioni?":                                                         $messaggio = "Fragen, ob die Kosten hizugef&uuml;gt und in der Eingabeseite f&uuml;r die Reservierungen gezeigt werden sollen?"; break;
case "Aggiungere al prezzo i costi aggiuntivi fissi associati alle tariffe?":  	$messaggio = "Addiere zum Preis die Aufschl&auml;ge, die mit dem gew&auml;hlten Preis verbunden sind?"; break;
case "Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con cui mostrarli": $messaggio = "Extrakosten zur Anzeige und ihre eventuellen Ersatznamen"; break;
case "Costo settimanale":                               $messaggio = "W&ouml;chentliche Kosten"; break;
case "Costo unico":                                  	$messaggio = "Einmalige Kosten"; break;
case "Costo giornaliero":                               $messaggio = "T&auml;gliche Kosten"; break;
case "nessuna":                                  	$messaggio = "keine Begr&uuml;ndung"; break;
case "comportati come se non vi fosse più disponibilità":        	$messaggio = "Anzeigen, dass kein Apartment frei ist"; break;
case "dai ancora disponibilità con questa frase alternativa":        	$messaggio = "Anzeigen, dass möglicherweise noch ein Apartment frei ist. Angezeigter Text (z.B.: Alternativvorschlag)"; break;
case "Disponibilità incerta per la tipologia scelta, per ulteriori informazioni contattateci via email":        	$messaggio = "Nichts mehr verfügbar unter diesen Voraussetzungen, aber wir können Ihnen eventuell eine Alternative anbieten. Bitte kontaktieren sie uns per Email bez&uuml;glich n&auml;herer Informationen."; break;
case "Mostrare la caparra se presente?":          	$messaggio = "Zeige Vorauszahlung falls vorhanden?"; break;
case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":        	$messaggio = "Zeige welche Tage voll der Periode entsprechen, in der nichts verfügbar ist?"; break;
case "Mostrare la form di richiesta prenotazione?":        	$messaggio = "Das Formular zur Reservierungsanforderung zeigen?"; break;
case "Indirizzo email a cui inviare le richieste di prenotazione":      $messaggio = "Email Addresse f&uuml;r Registrierungsanfragen"; break;
case "Tag html di apertura per la formattazione delle font":        	$messaggio = "&Ouml;ffnendes HTML-Tag zur Schriftformatierung"; break;
case "Tag html di chiusura per la formattazione delle font":        	$messaggio = "Schlie&szlig;endes HTML-Tag zur Schriftformatierung"; break;
case "Tag html di apertura per la formattazione delle font rosse":     	$messaggio = "&Ouml;ffnendes HTML-Tag zur Formatierung roter Schriftarten"; break;
case "Tag html di chiusura per la formattazione delle font rosse":      $messaggio = "Schlie&szlig;endes HTML-Tag zur Formatierung roter Schriftarten"; break;
case "Crea la pagina per la disponibilità":  	        $messaggio = "Verf&uuml;gbarkeitsseite anlegen"; break;
case "Controlla la disponibilità":                  	$messaggio = "Verf&uuml;gbarkeit pr&uuml;fen"; break;
case "dal":                                          	$messaggio = "von"; break;
case "al":                                          	$messaggio = "bis"; break;
case "per la tipologia":                          	$messaggio = "f&uuml;r Preiskategorie"; break;
case "tariffa":                                  	$messaggio = "Preis"; break;
case "per":                                          	$messaggio = "f&uuml;r"; break;
case "Le date sono sbagliate":                  	$messaggio = "Daten sind falsch"; break;
case "La tipologia è sbagliata":                  	$messaggio = "Preiskategorie ist falsch"; break;
case "è":                                          	$messaggio = "ist"; break;
case "pien":                                          	$messaggio = "voll"; break;
case "Non c'è più disponibilità nel periodo richiesto": $messaggio = "Nichts verf&uuml;gbar im gew&auml;hlten Zeitraum"; break;
case "nel periodo richiesto":                        	$messaggio = "im gew&uuml;nschten Zeitraum"; break;
case "nei periodi richiesti":                        	$messaggio = "in den gew&uuml;nschten Zeitr&auml;umen"; break;
case "per la tipologia":                          	$messaggio = "f&uuml;r Preiskategorie"; break;
case "per le tipologie richieste":                	$messaggio = "f&uuml;r die gew&uuml;nschten Kategorien"; break;
case "Non c'è più disponibilità":                	$messaggio = "Es ist nichts mehr verf&uuml;gbar"; break;
case "Periodo di":                                  	$messaggio = "Zeitraum von"; break;
case "Non c'è ancora nessuna tariffa per la tipologia richiesta in questo periodo":  $messaggio = "Diese Preiskonditionen sind in diesem Zeitraum f&uuml;r den angefragten Typ nicht verf&uuml;gbar."; break;
case "E' necessario inserire il numero di persone per questa tipologia":             $messaggio = "Die Personenanzahl wird ben&ouml;tigt f&uuml;r diesen Typ"; break;
case "Prezzo":                                  	$messaggio = "Preis"; break;
case "Caparra":                                  	$messaggio = "Anzahlung"; break;
case "compresi":                                  	$messaggio = "inklusive"; break;
case "di":                                          	$messaggio = "von"; break;
case "Nuovo controllo":                          	$messaggio = "Neue Pr&uuml;fung"; break;
case "Commento":                                  	$messaggio = "Kommentar"; break;
case "Invia la richiesta di prenotazione":          	$messaggio = "Buchung senden"; break;
case "Richiesta di prenotazione inviata":         	$messaggio = "Buchung wurde gesendet"; break;
case "Non è stato possibile inviare la richiesta":      $messaggio = "Es war nicht m&ouml;glich die Anfrage zu senden"; break;
case "da":                                          	$messaggio = "von"; break;
case "Periodo":                                  	$messaggio = "Zeitraum"; break;
case "Tariffa":                                  	$messaggio = "Preis"; break;
case "Costi aggiuntivi":                          	$messaggio = "Aufschl&auml;ge"; break;
case "Prezzo totale":                                  	$messaggio = "Endpreis"; break;
case "Riferimento":                                  	$messaggio = "Referenz"; break;
case "Richesta prenotazione":                          	$messaggio = "Reservierungsanfrage"; break;
case "modificare il valore sulla destra":          	$messaggio = "&auml;ndern des Wertes auf der rechten Seite"; break;
case "settimane":                                  	$messaggio = "Wochen"; break;
case "giorni":                                  	$messaggio = "Tage"; break;
case "settimana":                                  	$messaggio = "Woche"; break;
case "giorno":                                  	$messaggio = "Tag"; break;
case "La":                                          	$messaggio = "Die"; break;
case "Il":                                          	$messaggio = "Der/Die"; break;
case "piena":                                          	$messaggio = "voll"; break;
case "pieno":                                          	$messaggio = "voll"; break;
case "Una pagina chiamata":  			        $messaggio = "Eine Seite namens"; break;
case "è stata creata nella directory":  	        $messaggio = "wurde im angelegt im Ordner"; break;
case "Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"":	$messaggio = "Das Verzeichnis, in dem die Seiten abgelegt werden, k&ouml;nnen Sie in \"Konfigurieren und Anpassen\" &auml;ndern"; break;
case "INSERISCI QUI IL TUO HTML":                  	$messaggio = "HTML hier einf&uuml;gen"; break;
case "FINE DELLA PRIMA PARTE DELL'HTML PERSONALE":      $messaggio = "ENDE DES ERSTEN HTML TEILS"; break;
case "INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE":  $messaggio = "ANFANG DES ZWEITEN HTML TEILS"; break;
case "FINE DELLA SECONDA PARTE DELL'HTML PERSONALE":    $messaggio = "ENDE DES ZWEITEN HTML TEILS"; break;
case "Prefisso nel nome delle tabelle":                	$messaggio = "Prefix in Tabellenname"; break;
case "Parte html del file prima della form di disponibilità":  	$messaggio = "HTML Bereich der Datei vor dem Verf&uuml;gbarkeitsformular"; break;
case "Parte html del file dopo la form di disponibilità":     	$messaggio = "HTML Bereich der Datei nach dem Verf&uuml;gbarkeitsformular"; break;
case "0 per scelta libera":                          	$messaggio = "0 f&uuml;r unbegrenzt"; break;
case "Possibilità di aggiungere più tipologie da controllare contemporaneamente?":  $messaggio = "M&ouml;glichkeit um mehrere Typen hinzu zu f&uuml;gen um zeitgleich gepr&uuml;ft zu werden?"; break;
case "Numero massimo di tipologie":                  	$messaggio = "Maximal m&ouml;gliche Typen"; break;
case "Numero massimo di tipologie errato":          	$messaggio = "Maximale Anzahl der Typen ist falsch"; break;
case "Numero di":                                  	$messaggio = "Anzahl von"; break;
case "Il numero di":                                  	$messaggio = "Die Anzahl von"; break;
case "richiesto è sbagliato":                          	$messaggio = "ist falsch eingegeben"; break;
case "in":                                          	$messaggio = "in"; break;
case "Totale":                                  	$messaggio = "Gesamt"; break;
case "Aggiungi una nuova tipologia":                  	$messaggio = "Weitere Anfrage hinzuf&uuml;gen"; break;
case "Numero di colonne dei costi aggiuntivi errato":   $messaggio = "Die Anzahl der Spalten f&uuml;r die Aufschl&auml;ge ist falsch"; break;
case "Numero di colonne dei costi aggiuntivi":        	$messaggio = "Anzahl der Aufschl&auml;ge Spalten"; break;
case "tipologia":                                  	$messaggio = "Typ"; break;
case "Elimina questa tipologia":                  	$messaggio = "Typ l&ouml;schen"; break;
case "Scegliere le settimane in cui applicare":        	$messaggio = "W&auml;hlen Sie die Wochen, f&uuml;r die Sie anfragen wollen"; break;
case "Scegliere i giorni in cui applicare":          	$messaggio = "W&auml;hlen Sie die Tage, f&uuml;r die Sie anfragen wollen"; break;
case "Chiedere il numero di persone?":          	$messaggio = "Nach der Anzahl der Personen fragen?"; break;
case "persone":                                  	$messaggio = "Personen"; break;
case "Persone":                                  	$messaggio = "Personen"; break;
case "persona":                                  	$messaggio = "Person"; break;
case "Continua":                                  	$messaggio = "Weiter"; break;
case "singolare":                                  	$messaggio = "Singular"; break;
case "per ogni":                                  	$messaggio = "f&uuml;r jedes"; break;
case "Si deve inserire il numero delle persone per":    $messaggio = "Die Anzahl der Personen mu&szlig; eingegeben werden f&uuml;r"; break;
case "Errore nei servizi opzionali richiesti":        	$messaggio = "Fehler in den zus&auml;tzlich gebuchten Optionen"; break;
case "Numero massimo di persone":                  	$messaggio = "Maximale Bettenzahl"; break;
case "Se le persone superano la capienza massima utilizzare il costo aggiuntivo": $messaggio = "Wenn die Bettenzahl das Maximum übersteigt, fallen zusätzliche Kosten an"; break;
case "Se il costo può essere moltiplicato aggiungere al massimo":        	  $messaggio = "Wenn die Kosten multipliziert werden, maximal folgenden Faktor anwenden"; break;
case "letti aggiuntivi":                          	$messaggio = "Zusatzbetten"; break;
case "Numero massimo di persone errato":          	$messaggio = "Falsche maximale Bettenzahl"; break;
case "Numero massimo di letti aggiuntivi errato":       $messaggio = "Falsche Zahl an Zusatzbetten"; break;
case "supera la capienza massima della tipologia richiesta": $messaggio = "ist größer als die maximale Bettenkapazität dieser Kategorie"; break;
case "Si può creare un link verso questa pagina dal proprio sito internet":	$messaggio = "Sie k&ouml;nnen von Ihrer eigenen Internetseite einen Link zu dieser Seite anlegen"; break;
case "Cancella":                                  	$messaggio = "L&ouml;schen"; break;
case "tutte le pagine create":  		        $messaggio = "Alle erzeugten Seiten"; break;
case "Si è sicuri di voler <b style=\"color: red;\">cancellare</b>":   $messaggio = "Wollen Sie wirklich <b style=\"color: red;\">l&ouml;schen</b>"; break;
case "la pagina":				$messaggio = "diese Seite?"; break;
case "tutte le pagine create nella directory":	$messaggio = "jede Seite die angelegt wurde im Verzeichnis"; break;
case "tutte le pagine create nelle directory":	$messaggio = "jede Seite die angelegt wurde in den Verzeichnissen"; break;
case "Cancellate tutte le pagine":  		$messaggio = "Alle Seiten gel&ouml;scht"; break;
case "OK":                                      $messaggio = "OK"; break;
case "Modifica le frasi predefinite":           $messaggio = "Standardphrasen &auml;ndern"; break;
case "Frasi predefinite":                       $messaggio = "Standardphrasen"; break;
case "Mostrare il quadro indicativo della disponibilità?":  $messaggio = "Verf&uuml;gbarkeits&uuml;bersicht anzeigen?"; break;
case "Non mostrare":                            $messaggio = "Nicht zeigen"; break;
case "Colore di sfondo della tabella":          $messaggio = "Farbe Tabellenhintergrund"; break;
case "Colore del giorno di inizio settimana":   $messaggio = "Farbe f&uuml;r Wochenanfang"; break;
case "Colore dei periodi liberi":               $messaggio = "Farbe f&uuml;r freie Zeitr&auml;ume"; break;
case "Colore dei periodi occupati":             $messaggio = "Farbe f&uuml;r belegte Zeitr&auml;ume"; break;
case "Tag di apertura dei font della tabella":  $messaggio = "&Ouml;ffnendes Tag f&uuml;r Tabellenschriftart"; break;
case "Tag di chiusura dei font della tabella":  $messaggio = "Schlie&szlig;endes Tag f&uuml;r Tabellenschriftart"; break;
case "Quadro indicativo disponibilità":         $messaggio = "Verf&uuml;gbarkeits&uuml;bersicht"; break;
case "Gennaio":                                 $messaggio = "Januar"; break;
case "Febbraio":                                $messaggio = "Februar"; break;
case "Marzo":                                   $messaggio = "M&auml;rz"; break;
case "Maggio":                                  $messaggio = "Mai"; break;
case "Giugno":                                  $messaggio = "Juni"; break;
case "Luglio":                                  $messaggio = "Juli"; break;
case "Ottobre":                                 $messaggio = "Oktober"; break;
case "Dicembre":                                $messaggio = "Dezember"; break;
case "settimane di intervallo":                 $messaggio = "Intervall in Wochen"; break;
case "giorni di intervallo":                    $messaggio = "Intervall in Tagen"; break;
case "Estendere l'ultima data fino a quella massima disponibile nel database?":        	$messaggio = "Das Schlu&szlig;datum bis zum in der Datenbank vorhandenen Maximum ausdehnen?"; break;
case "necessario":                                  	$messaggio = "ben&ouml;tigt"; break;
case "non chiedere":                                  	$messaggio = "nicht abfragen"; break;
case "Inviare la richiesta di prenotazione come messaggio a":        	$messaggio = "Die Reservierungsanfrage als Mitteilung senden an"; break;
case "Campi della form da chiedere":           $messaggio = "abzufragende Formularfelder"; break;
case "Cognome":                                $messaggio = "Nachname"; break;
case "Genere":                                 $messaggio = "Geschlecht"; break;
case "Data di nascita":                        $messaggio = "Geburtsdatum"; break;
case "Documento":                              $messaggio = "Ausweisdokument"; break;
case "Nazione":                                $messaggio = "Staatsangeh&ouml;rigkeit"; break;
case "Città":                                  $messaggio = "Wohnort"; break;
case "Via":                                    $messaggio = "Stra&szlig;e"; break;
case "Numero civico":                          $messaggio = "Hausnummer"; break;
case "Codice postale":                         $messaggio = "Postleitzahl"; break;
case "Telefono":                               $messaggio = "Telefon"; break;
case "Secondo telefono":                       $messaggio = "Zweite Telefonnummer"; break;
case "Terzo telefono":                         $messaggio = "Dritte Telefonnummer"; break;
case "Fax":                                    $messaggio = "Fax"; break;
case "Orario stimato di arrivo":               $messaggio = "voraussichtl. Ankunftszeit"; break;
case "Metodo di pagamento della caparra":      $messaggio = "Zahlungsmethode f&uuml;r Anzahlung"; break;
case "Metodi di pagamento della caparra da chiedere e loro eventuali nomi sostitutivi":        	$messaggio = "Zahlungsarten f&uuml;r Anzahlung und ihre eventuellen Ersatznamen f&uuml;r die Anzeige"; break;
case "Campi della form personalizzati":          	$messaggio = "frei definierbare Formularfelder"; break;
case "tutti":                                          	$messaggio = "jeder"; break;
case "<small>campi necessari</small>":                	$messaggio = "<small>Pflichtfelder</small>"; break;
case "M":                                          	$messaggio = "M"; break;
case "F":                                          	$messaggio = "W"; break;
case "Prenota":                                  	$messaggio = "Buchen"; break;
case "--- OPPURE ---":                          	$messaggio = "--- ODER ---"; break;
case "Prenotazione istantanea con PayPal":          	$messaggio = "Sofort buchen mit PayPal"; break;
case "Accetta solo richieste che cominciano almeno dopo":        	$messaggio = "Nur Anfragen annehmen, die sp&auml;testens beginnen nach dem"; $tr = 1; break;
case "Mostrare i calendari per la scelta delle date?":  $messaggio = "Kalender zeigen, um Daten auszuw&auml;hlen?"; break;
case "Stile riquadro calendario":                  	$messaggio = "Kalender Rahmenstil"; break;
case "Stile tabella calendario":                  	$messaggio = "Kalender Tabellenstil"; break;
case "Stile bottoni interni":                          	$messaggio = "Stil interne Buttons"; break;
case "Stile bottone apertura":                  	$messaggio = "Button-Stil"; break;
case "Colore date attive":                          	$messaggio = "Farbe aktive Daten"; break;
case "Colore data selezionata":                  	$messaggio = "Farbe f&uuml;r gew&auml;hltes Datum"; break;
case "Chiudi":                                  	$messaggio = "Schlie&szlig;en"; break;
case "mostra":                                  	$messaggio = "Zeigen"; break;
case "non mostrare":                                  	$messaggio = "Nicht anzeigen"; break;
case "Inviare una copia della email di richiesta prenotazione al richiedente?":        	$messaggio = "Eine Kopie der Reservierungsanfrage per E-Mail an den Interessenten senden?"; break;
case "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile":        	$messaggio = "Wir haben Ihre Reservierungsanfrage erhalten und geben Ihnen baldm&ouml;glichst Bescheid"; break;
case "Copia della richiesta è stata inviata a":        	$messaggio = "Eine Kopie der Anfrage wurde gesendet an"; break;
case "NON MODIFICARE MANUALMENTE":                  	$messaggio = "NICHT VON HAND BEARBEITEN"; break;
case "Anteporre il nome della valuta?":          	$messaggio = "W&auml;hrungszeichen vor den Preis setzen?"; break;
case "Stile della tabella che racchiude la form di prenotazione":  $messaggio = "Stil der Tabelle, welches das Buchungsformular umschlie&szlig;t"; break;
case "Origine della prenotazione":                  	$messaggio = "Herkunft der Reservierung"; break;
case "Cartella":                                  	$messaggio = "Verzeichnis"; break;
case "Pagina cancellata":  			        $messaggio = "Seite gel&ouml;scht"; break;
case "Importa le pagine dalla cartella":  	        $messaggio = "Seiten importieren aus Verzeichnis"; break;
case "alla cartella":                                  	$messaggio = "in Verzeichnis"; break;
case "Si è sicuri di voler importare le pagine dalla cartella":	$messaggio = "Sind Sie sichern, dass Sie die Seiten importieren wollen aus dem Verzeichnis"; break;
case "eventuali pagine già presenti nella cartella":	$messaggio = "Seiten die schon vorhanden sind in dem Verzeichnis"; break;
case "verranno <b style=\"font-weight: normal; color: red;\">sovrascritte</b>":	$messaggio = "werden <b style=\"font-weight: normal; color: red;\">&uuml;berschrieben</b>"; break;
case "Pagine importate":  			        $messaggio = "Seiten importiert"; break;
case "con i servizi opzionali selezionati":          	$messaggio = "mit ausgew&auml;hlten optionalen Diensten"; break;
case "Url del file css per la modalità frame":        	$messaggio = "Url einer CSS-Datei f&uuml;r Darstellung mit Frames"; break;
case "Utilizza per l'aspetto della pagina":  	        $messaggio = "Benutze f&uuml;r Seitendarstellung"; break;
case "html personalizzato":                          	$messaggio = "Allgemeines HTML"; break;
case "il tema chiamato":                          	$messaggio = "das Thema"; break;
case "Colore del tema":                          	$messaggio = "Farbe des Themas"; break;
case "Data di arrivo":                          	$messaggio = "Ankunftsdatum"; break;
case "Data di partenza":                          	$messaggio = "Abreisedatum"; break;
case "Tipologia":                                  	$messaggio = "Typ"; break;
case "default - frame orizzontale":                  	$messaggio = "Vorgabe - waagrechter Frame"; break;
case "Condizioni da accettare nella form":          	$messaggio = "Vereinbarungen, die im Formular akzeptiert werden m&uuml;ssen"; break;
case "Accetto":                                  	$messaggio = "Ich akzeptiere"; break;
case "documento":                                  	$messaggio = "Dokument"; break;
case "larghezza":  				        $messaggio = "Breite"; break;
case "altezza":  				        $messaggio = "H&ouml;he"; break;
case "Dalla modalidà frame, aprire il secondo passo in una nuova finestra?":	$messaggio = "Wenn Darstellung mit Frames, den zweiten Schritt in einem neuen Fenster &ouml;ffnen?"; break;
case "Geometria della nuova finestra":  	$messaggio = "Abmessungen f&uuml;r neues Fenster"; break;
case "Torna alla HOME":  			$messaggio = "Zur&uuml;ck zur Startseite"; break;
case "URL della home":  			$messaggio = "URL der Startseite"; break;
case "URL del logo":  				$messaggio = "URL f&uuml;r Logo"; break;
case "Valore del tema":  			$messaggio = "Wert f&uuml;r Thema"; break;
case "Esempio di codice html per includere il primo passo della form in modalità frame su altre pagine del sito":	$messaggio = "Example of html code to include the first step of the form in framed mode on other website pages"; break;
case "selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla":	$messaggio = "W&auml;hle \"Allgemeines HTML\" in \"Seitendarstellung\" um es zu &auml;ndern"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "il":  					$messaggio = "the"; break;
case "Crea Pagine Web":  			$messaggio = "Create Web Pages"; break;
case "Postgresql":  				$messaggio = "Postgresql"; break;
case "Mysql":  					$messaggio = "Mysql"; break;
case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Email":  					$messaggio = "Email"; break;
case "Email alternativa":  			$messaggio = "Alternative email"; break;
case "Email certificata (PEC) o codice destinatario":	$messaggio = "Certified email"; break;
case "Aprile":  				$messaggio = "April"; break;
case "Agosto":  				$messaggio = "August"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Novembre":  				$messaggio = "November"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Regione":  				$messaggio = "Region"; break;
case "<span style=\\\"color: red;\\\">*</span>":	$messaggio = "<span style=\\\"color: red;\\\">*</span>"; break;
case "<small>*</small>":  			$messaggio = "<small>*</small>"; break;
case "Mostrare il bottone per prenotare con la pagina di prenotazione immediata se presente?":	$messaggio = "Show the button to book with the instant booking page if present?"; break;
case "Nome file della pagina di prenotazione immediata":	$messaggio = "Instant booking page filename"; break;
case "Numero di settimane dopo cui prendere richieste errato":	$messaggio = "Wrong number of weeks after which take requests"; $tr = 1; break;
case "Numero di giorni dopo cui prendere richieste errato":	$messaggio = "Wrong number of days after which take requests"; $tr = 1; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Align availability with arrival date?"; break;
case "Importa":  				$messaggio = "Import"; break;
case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
case "nomi dall'utente delle personalizzazioni":	$messaggio = "names from customizations user"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
case "aggiunto al commento":  			$messaggio = "added to comment"; break;
case "aggiunto al campo":  			$messaggio = "added to field"; break;
case "del cliente":  				$messaggio = "in client data"; break;
case "URL file css":  				$messaggio = "URL of css file"; break;
case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "mai":  					$messaggio = "never"; break;
case "se possibile":  				$messaggio = "when possible"; break;
case "sempre":  				$messaggio = "always"; break;
case "posizioni vicine":  			$messaggio = "nearby positions"; break;
case "con posizioni vicine":  			$messaggio = "with nearby positions"; break;
case "Indirizzi alternativi da cui la pagina è raggiungibile":	$messaggio = "Alternative addresses from which the page can be reached"; break;
case "sicuro":  				$messaggio = "secure"; break;
case "usare uno spazio per non mostrare il costo nei dettagli":	$messaggio = "use a space to don't show the cost in the details"; break;
case "Codici promozionali":  			$messaggio = "Promotional codes"; break;
case "Il codice":  				$messaggio = "The code"; break;
case "aggiunge":  				$messaggio = "adds"; break;
case "rimuove":  				$messaggio = "removes"; break;
case "Codice promozionale":  			$messaggio = "Promotional code"; break;
case "Solo quelli selezionati per essere mostrati":	$messaggio = "only the ones selected to be shown"; break;
case "Codice promozionale applicato":  		$messaggio = "Promotional code applied"; break;
case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "some extra costs with promotional code"; break;
case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "are not associated to any rate, some of their characteristics may be altered if not compatible"; break;
case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
case "titolo html":  				$messaggio = "html title"; break;
case "titolo":  				$messaggio = "title"; break;
case "Si deve inserire almeno una persona che possa essere legalmente responsabile":	$messaggio = "You must include at least one person who can be legally responsible"; break;
case "Solo quando non c'è disponibilità":  	$messaggio = "Only when there is no availability"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Raggruppamento":  			$messaggio = "Grouping"; break;
case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
case "Seconda email":  				$messaggio = "Second email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "must not contain \"php\" and must end with \".js\""; break;
case "notte":  					$messaggio = "night"; break;
case "notti":  					$messaggio = "nights"; break;
case "cambia date":  				$messaggio = "change dates"; break;
case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "For this rate you have to insert at least"; break;
case "Secondo cognome":  			$messaggio = "Second surname"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

# NAME OF THE FILE: same rules as varibles below
case "mdl_disponibilita":                          	$messaggio = "verfuegbarkeitscheck"; break;

} # fine switch ($messaggio)
} # fine if (substr((string) $messaggio,0,4) != "var_")


else {
switch ($messaggio) {

# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only ASCII a-z, A-Z, 0-9 
# and _ (underscore). No spaces, no accents! No special characters! There must not be 2 with the same name.
# NOTE: names of variables are only shown when editing files, actually *they don't need to be translated*
case "var_nome_pagina":                          	$messaggio = "var_Seiten_Name"; break;
case "var_anno":                                  	$messaggio = "var_Jahr"; break;
case "var_tipo_db":                                  	$messaggio = "var_db_Typ"; break;
case "var_nome_db":                                  	$messaggio = "var_db_Name"; break;
case "var_computer_db":                          	$messaggio = "var_db_Host"; break;
case "var_porta_db":                                  	$messaggio = "var_db_Port"; break;
case "var_utente_db":                                  	$messaggio = "var_db_benutzer"; break;
case "var_password_db":                          	$messaggio = "var_db_passwort"; break;
case "var_carica_estensione_db":                  	$messaggio = "var_db_Erweiterung_laden"; break;
case "var_prefisso_tabelle_db":                  	$messaggio = "var_db_Tabellen_prefix"; break;
case "var_stile_soldi":                          	$messaggio = "var_Waehrungsformat"; break;
case "var_stile_data":                          	$messaggio = "var_Datumsformat"; break;
case "var_tariffe_mostra":                          	$messaggio = "var_anzuzeigende_Preisgruppen"; break;
case "var_nomi_tariffe_imposte":                  	$messaggio = "var_Preisgruppennamen"; break;
case "var_aggiungi_costi_fissi":                  	$messaggio = "var_Aufschlaege_addieren"; break;
case "var_chiedi_costi_aggiuntivi_di_pag_inserzione":   $messaggio = "var_frage_nach_Aufschlaege_in_der_Eingabseite"; break;
case "var_nomi_costi_agg_imposti":                  	$messaggio = "var_Name_fuer_Aufschlaege"; break;
case "var_assegna_con_regola2":                  	$messaggio = "var_mit_Regel_1_verbinden"; break;
case "var_considera_motivazioni_regola1":          	$messaggio = "var_Grund_fuer_die_Anwendung_von_Regel_1"; break;
case "var_mostra_frase_alternativa_regola1":          	$messaggio = "var_zeige_Alternative_fuer_Regel_1"; break;
case "var_mostra_caparra":                          	$messaggio = "var_zeige_Anzahlung"; break;
case "var_mostra_richiesta_via_mail":                  	$messaggio = "var_zeige_Emailanfrage"; break;
case "var_indirizzo_email":                          	$messaggio = "var_Email_Adresse"; break;
case "var_mostra_giorni_pieni":                  	$messaggio = "var_zeige_alle_Tage"; break;
case "var_apertura_tag_font":                          	$messaggio = "var_font_tag_Anfang"; break;
case "var_chiusura_tag_font":                          	$messaggio = "var_font_tag_schliessen"; break;
case "var_fr_Valuta_sing":                          	$messaggio = "var_phr_Waehrung_Einzahl"; break;
case "var_fr_Valuta_plur":                          	$messaggio = "var_phr_Waehrung_Mehrzahl"; break;
case "var_fr_Controlla_la_disponibilita":          	$messaggio = "var_phr_Verfuegbarkeit_pruefen"; break;
case "var_fr_dal":                                  	$messaggio = "var_phr_von"; break;
case "var_fr_al":                                  	$messaggio = "var_phr_zu"; break;
case "var_fr_per_la_tipologia":                  	$messaggio = "var_phr_fuer_Typ"; break;
case "var_fr_tariffa":                          	$messaggio = "var_phr_Preis"; break;
case "var_fr_per":                                  	$messaggio = "var_phr_fuer"; break;
case "var_fr_Le_date_sono_sbagliate":                  	$messaggio = "var_phr_Daten_falsch"; break;
case "var_fr_La_tipologia_e_sbagliata":          	$messaggio = "var_phr_Typ_falsch"; break;
case "var_fr_parola_La":                          	$messaggio = "var_phr_Wort_das_die"; break;
case "var_fr_parola_settimana":                  	$messaggio = "var_phr_wort_Woche"; break;
case "var_fr_est":                                  	$messaggio = "var_phr_ist"; break;
case "var_fr_pien":                                  	$messaggio = "var_phr_voll"; break;
case "var_fr_lettera_a":                          	$messaggio = "var_phr_Brief_Einzahl"; break;
case "var_fr_Non_c_e_piu_disponibilita_nel_periodo_richiesto":        	$messaggio = "var_phr_Nichts_verfuegbar_im_entsprechenden_Zeitraum"; break;
case "var_fr_C_e_ancora_disponibilita":          	$messaggio = "var_phr_Verfuegbarkeit_ist_noch_gegeben"; break;
case "var_fr_Non_c_e_piu_disponibilita":          	$messaggio = "var_phr_Verfuegbarkeit_ist_nicht_mehr_gegeben"; break;
case "var_fr_alternativa_regola1":                  	$messaggio = "var_phr_Regel_1_Alternative"; break;
case "var_fr_Periodo_di":                          	$messaggio = "var_phr_Zeitraum_von"; break;
case "var_fr_parola_settimane":                  	$messaggio = "var_phr_Wort_Wochen"; break;
case "var_fr_Non_c_e_tariffa_per_questa_tipologia_ecc": $messaggio = "var_phr_Es_existiert_noch_kein_Preis_fuer_den_angefragten_Typ_etc"; break;
case "var_fr_Prezzo":                                  	$messaggio = "var_phr_Preis"; break;
case "var_fr_Caparra":                          	$messaggio = "var_phr_Anzahlung"; break;
case "var_fr_compresi":                          	$messaggio = "var_phr_inklusive"; break;
case "var_fr_di":                                  	$messaggio = "var_phr_von2"; break;
case "var_fr_Nuovo_controllo":                  	$messaggio = "var_phr_Neu_pruefen"; break;
case "var_fr_Commento":                          	$messaggio = "var_phr_Kommentar"; break;
case "var_fr_Invia_la_richiesta_di_prenotazione":       $messaggio = "var_phr_Reservierungsanfrage_absenden"; break;
case "var_fr_Non_e_stato_possibile_inviare_la_richiesta": $messaggio = "var_phr_Versenden_fehlgeschlagen"; break;
case "var_fre_Commento":                          	$messaggio = "var_phre_Kommentar"; break;
case "var_fre_Periodo":                          	$messaggio = "var_phre_Zeitraum"; break;
case "var_fre_dal":                                  	$messaggio = "var_phre_von"; break;
case "var_fre_al":                                  	$messaggio = "var_phre_zu"; break;
case "var_fre_Tariffa":                          	$messaggio = "var_phre_Preis"; break;
case "var_fre_Costi_aggiuntivi":                  	$messaggio = "var_phre_Aufschlaege"; break;
case "var_fre_sett":                                  	$messaggio = "var_phre_Wochen"; break;
case "var_fre_Prezzo_totale":                          	$messaggio = "var_phre_Gesamtpreis"; break;
case "var_fre_Riferimento":                          	$messaggio = "var_phre_RReferenz"; break;
case "var_fre_Caparra":                          	$messaggio = "var_phre_Anzahlung"; break;
case "var_fre_Richesta_prenotazione":                  	$messaggio = "var_phre_Reservierungsanfrage"; break;
case "var_periodi_menu":                          	$messaggio = "var_menu_Zeitraeume"; break;
case "var_fr_appartamenti":                          	$messaggio = "var_phr_Apartments"; break;
case "var_chiedi_numero_appartamenti_per_tipologia":    $messaggio = "var_nach_Apartmentnummer_fragen_fuer_Typ"; break;
case "var_massimo_numero_appartamenti_per_tipologia":   $messaggio = "var_maximale_Anzahl_von_Apartments_fuer_Typ"; break;
case "var_aggiungi_altre_tipologie":                  	$messaggio = "var_andere_Typen_hinzufuegen"; break;
case "var_massimo_numero_altre_tipologie":          	$messaggio = "var_maximum_anderer_Typen"; break;
case "var_fr_Numero_di":                          	$messaggio = "var_phr_Anzahl_von"; break;
case "var_fr_Il_numero_di":                          	$messaggio = "var_phr_Die_Anzahl_der"; break;
case "var_fr_richiesto_e_sbagliato":                  	$messaggio = "var_phr_eingegebenen_ist_falsch"; break;
case "var_fr_Totale":                                  	$messaggio = "var_phr_Gesamt"; break;
case "var_fre_Numero_di_appartamenti":          	$messaggio = "var_phr_Anzahl_der_Apartments"; break;
case "var_fr_Aggiungi_una_nuova_tipologia":        	$messaggio = "var_phr_neuen_Typ_hinzufuegen"; break;
case "var_numero_colonne_costi_aggiuntivi":          	$messaggio = "var_Aufschlaege_Spaltennummer"; break;
case "var_fr_per_la_tipologia":                  	$messaggio = "var_phr_fuer_Typ"; break;
case "var_fr_per_le_tipologie_richieste":          	$messaggio = "var_phr_fuer_angefragte_Typen"; break;
case "var_fr_nel_periodo_richiesto":                  	$messaggio = "var_phr_im_geforderten_Zeitraum"; break;
case "var_fr_nei_periodi_richiesti":                  	$messaggio = "var_phr_in_den_geforderten_Zeitraeumen"; break;
case "var_fr_tipologia":                          	$messaggio = "var_phr_Typ"; break;
case "var_fr_Torna_indietro":                          	$messaggio = "var_phr_Zurueck"; break;
case "var_fr_Elimina_questa_tipologia":          	$messaggio = "var_fr_diesen_Typ_loeschen"; break;
case "var_fr_con_i_servizi_opzionali_selezionati":      $messaggio = "var_with_selected_optional_services"; break;

case "var_lingua_modello":  			$messaggio = "var_template_language"; break;
case "var_cartella_mysql_lock":  		$messaggio = "var_mysql_lock_dir"; break;
case "var_anteponi_nome_valuta":  		$messaggio = "var_currency_name_in_front"; break;
case "var_utente_liste":  			$messaggio = "var_lists_user"; break;
case "var_estendi_ultima_data":  		$messaggio = "var_extend_last_date"; break;
case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_extra_costs_to_show"; break;
case "var_categorie_costi_agg_imposte":  	$messaggio = "var_imposed_extra_costs_categories"; break;
case "var_campi_codici_promo":  		$messaggio = "var_fields_promo_codes"; break;
case "var_costi_campi_codici_promo":  		$messaggio = "var_costs_fields_promo_codes"; break;
case "var_mostra_bottone_paypal":  		$messaggio = "var_show_paypal_button"; break;
case "var_nome_modello_paypal":  		$messaggio = "var_paypal_template_name"; break;
case "var_origine_prenotazione":  		$messaggio = "var_reservation_origin"; break;
case "var_apertura_tag_font_rosse":  		$messaggio = "var_red_font_tag_opening"; break;
case "var_chiusura_tag_font_rosse":  		$messaggio = "var_red_font_tag_closing"; break;
case "var_chiedi_numero_persone":  		$messaggio = "var_ask_people_number"; break;
case "var_periodi_no_richieste":		$messaggio = "var_periods_no_requests"; break;
case "var_mostra_calendario_scelta_date":  	$messaggio = "var_show_dates_picker_calendar"; break;
case "var_stile_riquadro_calendario":  		$messaggio = "var_calendar_box_style"; break;
case "var_stile_tabella_calendario":  		$messaggio = "var_calendar_table_style"; break;
case "var_stile_bottoni_calendario":  		$messaggio = "var_calendar_buttons_style"; break;
case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_open_calendar_button_style"; break;
case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calendar_date"; break;
case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
case "var_file_css_frame":  			$messaggio = "var_framed_css_file"; break;
case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_open_new_window_from_frame"; break;
case "var_larghezza_finestra_da_frame":  	$messaggio = "var_window_from_frame_width"; break;
case "var_altezza_finestra_da_frame":  		$messaggio = "var_window_from_frame_height"; break;
case "var_tema_modello":  			$messaggio = "var_template_theme"; break;
case "var_colore_tema":  			$messaggio = "var_theme_color"; break;
case "var_valore_tema":  			$messaggio = "var_theme_value"; break;
case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_align_availability_with_arrival"; break;
case "var_mostra_date_passate":  		$messaggio = "var_show_past_dates"; break;
case "var_fr_E_necessario_inserire_il_numero_di_persone_ecc":	$messaggio = "var_fr_The_number_of_people_is_needed_etc"; break;
case "var_fr_Nome":  				$messaggio = "var_phr_Name"; break;
case "var_fr_Email":  				$messaggio = "var_phr_Email"; break;
case "var_fr_Email_alternativa":  		$messaggio = "var_phr_Alternative_email"; break;
case "var_fr_Email_certificata_o_codice_destinatario":	$messaggio = "var_phr_Certified_email"; break;
case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_phr_Request_for_reservation_sent"; break;
case "var_fr_da":  				$messaggio = "var_phr_from2"; break;
case "var_fre_Email":  				$messaggio = "var_phre_Email"; break;
case "var_fre_Email_alternativa":  		$messaggio = "var_phre_Alternative_email"; break;
case "var_fre_Email_certificata_o_codice_destinatario":	$messaggio = "var_phre_Certified_email"; break;
case "var_fre_Nome":  				$messaggio = "var_phre_Name"; break;
case "var_fre_Valuta_della_caparra":  		$messaggio = "var_phre_Deposit_currency"; break;
case "var_fr_Richesta_prenotazione":  		$messaggio = "var_phr_Reservation_request"; break;
case "var_fr_appartamento":  			$messaggio = "var_phr_apartment"; break;
case "var_cerca_appartamenti_vicini":  		$messaggio = "var_search_nearby_apartments"; break;
case "var_fr_in":  				$messaggio = "var_phr_in"; break;
case "var_fre_Persone":  			$messaggio = "var_phre_People"; break;
case "var_fr_Scegliere_le_settimane_in_cui_applicare":	$messaggio = "var_phr_Choose_the_weeks_to_be_applied_for"; break;
case "var_fr_persone":  			$messaggio = "var_phr_people"; break;
case "var_fr_persona":  			$messaggio = "var_phr_person"; break;
case "var_fr_Continua":  			$messaggio = "var_phr_Continue"; break;
case "var_fr_per_ogni":  			$messaggio = "var_phr_for_each"; break;
case "var_fr_Si_deve_inserire_il_numero_delle_persone_per":	$messaggio = "var_phr_The_number_of_people_must_be_inserted_for"; break;
case "var_fr_Errore_nei_servizi_opzionali_richiesti":	$messaggio = "var_phr_Error_in_requested_optional_services"; break;
case "var_massimo_numero_persone":  		$messaggio = "var_maximum_number_people"; break;
case "var_costo_aggiungi_letti":  		$messaggio = "var_cost_add_beds"; break;
case "var_massimo_numero_letti_aggiuntivi":  	$messaggio = "var_maximum_number_extra_beds"; break;
case "var_fr_supera_la_capienza_massima_della_tipologia_richiesta":	$messaggio = "var_phr_is_bigger_than_the_maximum_capacity_of_requested_type"; break;
case "var_mostra_quadro_disponibilita":  	$messaggio = "var_show_availability_overview"; break;
case "var_raggruppa_quadro_disponibilita_con_regola_2":	$messaggio = "var_group_availability_overview_with_rule_2"; break;
case "var_raggruppa_quadro_disponibilita_con_persone":	$messaggio = "var_group_availability_overview_with_people"; break;
case "var_colore_sfondo_quadro_disponibilita":	$messaggio = "var_background_color_availability_overview"; break;
case "var_colore_inizio_settimana_quadro_disponibilita":	$messaggio = "var_color_week_beginning_availability_overview"; break;
case "var_colore_libero_quadro_disponibilita":	$messaggio = "var_color_free_availability_overview"; break;
case "var_colore_occupato_quadro_disponibilita":	$messaggio = "var_color_full_availability_overview"; break;
case "var_apertura_font_quadro_disponibilita":	$messaggio = "var_opening_font_availability_overview"; break;
case "var_chiusura_font_quadro_disponibilita":	$messaggio = "var_closing_font_availability_overview"; break;
case "var_mostra_numero_liberi_quadro_disponibilita":	$messaggio = "var_show_free_number_availability_overview"; break;
case "var_fr_Quadro_indicativo_disponibilita":	$messaggio = "var_phr_Indicative_availability_overview"; break;
case "var_fr_Gennaio":  			$messaggio = "var_phr_January"; break;
case "var_fr_Febbraio":  			$messaggio = "var_phr_February"; break;
case "var_fr_Marzo":  				$messaggio = "var_phr_March"; break;
case "var_fr_Aprile":  				$messaggio = "var_phr_April"; break;
case "var_fr_Maggio":  				$messaggio = "var_phr_May"; break;
case "var_fr_Giugno":  				$messaggio = "var_phr_June"; break;
case "var_fr_Luglio":  				$messaggio = "var_phr_July"; break;
case "var_fr_Agosto":  				$messaggio = "var_phr_August"; break;
case "var_fr_Settembre":  			$messaggio = "var_phr_September"; break;
case "var_fr_Ottobre":  			$messaggio = "var_phr_October"; break;
case "var_fr_Novembre":  			$messaggio = "var_phr_November"; break;
case "var_fr_Dicembre":  			$messaggio = "var_phr_December"; break;
case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
case "var_chiedi_email2":  			$messaggio = "var_ask_email2"; break;
case "var_chiedi_email_cert":  			$messaggio = "var_ask_cert_email"; break;
case "var_chiedi_sesso":  			$messaggio = "var_ask_sex"; break;
case "var_chiedi_datanascita":  		$messaggio = "var_ask_birthdate"; break;
case "var_chiedi_documento":  			$messaggio = "var_ask_document"; break;
case "var_chiedi_nazione":  			$messaggio = "var_ask_nation"; break;
case "var_chiedi_citta":  			$messaggio = "var_ask_city"; break;
case "var_chiedi_regione":  			$messaggio = "var_ask_region"; break;
case "var_chiedi_via":  			$messaggio = "var_ask_street"; break;
case "var_chiedi_numcivico":  			$messaggio = "var_ask_housenumber"; break;
case "var_chiedi_cap":  			$messaggio = "var_ask_postalcode"; break;
case "var_chiedi_telefono":  			$messaggio = "var_ask_telephone"; break;
case "var_chiedi_telefono2":  			$messaggio = "var_ask_telephone2"; break;
case "var_chiedi_telefono3":  			$messaggio = "var_ask_telephone3"; break;
case "var_chiedi_fax":  			$messaggio = "var_ask_fax"; break;
case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
case "var_chiedi_valutapagamento":  		$messaggio = "var_ask_paymentcurrency"; break;
case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_ask"; break;
case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
case "var_campi_form_personalizzati":  		$messaggio = "var_custom_form_fields"; break;
case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_ask_custom_form_fields"; break;
case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
case "var_campi_form_doc_condizioni":  		$messaggio = "var_doc_conditions_form_fields"; break;
case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_ask_doc_conditions_form_fields"; break;
case "var_fr_Cognome":  			$messaggio = "var_phr_Surname"; break;
case "var_fr_Genere":  				$messaggio = "var_phr_Gender"; break;
case "var_fr_Data_di_nascita":  		$messaggio = "var_phr_Birthdate"; break;
case "var_fr_Documento":  			$messaggio = "var_phr_Document"; break;
case "var_fr_Nazione":  			$messaggio = "var_phr_Nation"; break;
case "var_fr_Citta":  				$messaggio = "var_phr_City"; break;
case "var_fr_Regione":  			$messaggio = "var_phr_Region"; break;
case "var_fr_Via":  				$messaggio = "var_phr_Street"; break;
case "var_fr_Numero_civico":  			$messaggio = "var_phr_House_number"; break;
case "var_fr_Codice_postale":  			$messaggio = "var_phr_Postal_code"; break;
case "var_fr_Telefono":  			$messaggio = "var_phr_Telephone"; break;
case "var_fr_Secondo_telefono":  		$messaggio = "var_phr_Second_telephone"; break;
case "var_fr_Terzo_telefono":  			$messaggio = "var_phr_Third_telephone"; break;
case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
case "var_fr_Valuta_della_caparra":		$messaggio = "var_phr_Deposit_currency"; break;
case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
case "var_fre_Genere":  			$messaggio = "var_phre_Gender"; break;
case "var_fre_Data_di_nascita":  		$messaggio = "var_phre_Birthdate"; break;
case "var_fre_Documento":  			$messaggio = "var_phre_Document"; break;
case "var_fre_Nazione":  			$messaggio = "var_phre_Nation"; break;
case "var_fre_Citta":  				$messaggio = "var_phre_City"; break;
case "var_fre_Regione":  			$messaggio = "var_phre_Region"; break;
case "var_fre_Via":  				$messaggio = "var_phre_Street"; break;
case "var_fre_Numero_civico":  			$messaggio = "var_phre_House_number"; break;
case "var_fre_Codice_postale":  		$messaggio = "var_phre_Postal_code"; break;
case "var_fre_Telefono":  			$messaggio = "var_phre_Telephone"; break;
case "var_fre_Secondo_telefono":  		$messaggio = "var_phre_Second_telephone"; break;
case "var_fre_Terzo_telefono":  		$messaggio = "var_phre_Third_telephone"; break;
case "var_fre_Fax":  				$messaggio = "var_phre_Fax"; break;
case "var_fre_Codice_fiscale":  		$messaggio = "var_phre_Fiscal_code"; break;
case "var_fre_Partita_iva":  			$messaggio = "var_phre_VAT_number"; break;
case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_phre_Estimated_arrival_time"; break;
case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phre_Deposit_payment_method"; break;
case "var_fr_campi_necessari":  		$messaggio = "var_phr_required_fields"; break;
case "var_fr_piena":  				$messaggio = "var_phr_full"; break;
case "var_fr_asterisco_rosso":  		$messaggio = "var_phr_red_asterisk"; break;
case "var_fr_asterisco_nero":  			$messaggio = "var_phr_black_asterisk"; break;
case "var_fr_maschile":  			$messaggio = "var_phr_male"; break;
case "var_fr_femminile":  			$messaggio = "var_phr_female"; break;
case "var_fr_Prenota":  			$messaggio = "var_phr_Book"; break;
case "var_fr_OPPURE_linee":  			$messaggio = "var_fr_OR_dashes"; break;
case "var_fr_Prenotazione_istantanea_con_PayPal":	$messaggio = "var_fr_Instant_booking_with_PayPal"; break;
case "var_fr_Chiudi":  				$messaggio = "var_phr_Close"; break;
case "var_manda_copia_richiesta_email":  	$messaggio = "var_send_copy_of_request_email"; break;
case "var_fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc":	$messaggio = "var_phr_We_have_received_your_reservation_request_etc"; break;
case "var_fr_Copia_della_richiesta_e_stata_inviata_a":	$messaggio = "var_phr_A_copy_of_the_request_has_been_sent_to"; break;
case "var_fr_Data_di_arrivo":  			$messaggio = "var_phr_Arrival_date"; break;
case "var_fr_Data_di_partenza":  		$messaggio = "var_phr_Departure_date"; break;
case "var_fr_Tipologia":  			$messaggio = "var_phr_Type"; break;
case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; break;
case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
case "var_fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc":	$messaggio = "var_phr_You_must_include_at_least_one_person_who_can_etc"; break;
case "var_fr_notte":  				$messaggio = "var_phr_night"; break;
case "var_fr_notti":  				$messaggio = "var_phr_nights"; break;
case "var_fr_cambia_date":  			$messaggio = "var_phr_change_dates"; break;
case "var_fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di":	$messaggio = "var_phr_For_this_rate_you_have_to_insert_at_least"; break;
case "var_":  		$messaggio = "var_"; break;
case "var_":  		$messaggio = "var_"; break;
case "var_chiedi_cognome2":  			$messaggio = "var_ask_surname2"; break;
case "var_fr_Secondo_cognome":  		$messaggio = "var_phr_Second_surname"; break;
} # fine switch ($messaggio)
} # fine else if (substr((string) $messaggio,0,4) != "var_")



?>
